#!/bin/bash
function abspath() {
    SELF=$(readlink -f "$0")
    HERE=${SELF%/*}

    # generate absolute path from relative path
    # $1     : relative filename
    # return : absolute path
    if [ -d "$1" ]; then
        # dir
        (cd "$1"; pwd)
    elif [ -f "$1" ]; then
        # file
        if [[ $1 = /* ]]; then
            echo "$1"
        elif [[ $1 == */* ]]; then
            echo "$(cd "${1%/*}"; pwd)/${1##*/}"
        else
            echo "$(pwd)/$1"
        fi
    else
        echo "${HERE}/$1"
    fi
}

str=`curl -V`
if [[ $str =~ "x86_64" ]] && [[ $str =~ "libcurl" ]]
then
    echo 'Curl OK'
else
    echo 'Требуется Curl x86_64'
    exit
fi
echo "Редактирование настроек"
#USER=`logname`
#if [[ -z $USER ]]; then
#    read -p "Укажите имя пользователя, для запуска службы: " USER
#fi
read -p "Укажите имя пользователя, для запуска службы: " USER
if [[ -z $USER ]]; then
    echo "Требуется указать имя пользователя"
    exit
fi
read -p "Укажите путь к папке с сервером ИРБИС64: " SERVER64
if [[ -z $SERVER64 ]]; then
    echo "Требуется указать путь к папке с базами данных SERVER64"
    exit
fi
SERVER64=$(abspath $SERVER64)
if [ ! -d "$SERVER64" ]; then
    echo "Путь $SERVER64 не существует, либо не является директорией"
    exit
fi
DATAI=$SERVER64/datai
if [ ! -d "$DATAI" ]; then
    echo "Путь $DATAI не существует, либо не является директорией"
    exit
fi
HTDOCS_DEFAULT=/var/www/html
read -p "Укажите путь к папке htdocs ($HTDOCS_DEFAULT): " HTDOCS
if [[ -z $HTDOCS ]]; then
    HTDOCS=$HTDOCS_DEFAULT
fi
if [ ! -d "$HTDOCS" ]; then
    echo "Путь $HTDOCS не существует, либо не является директорией"
    exit
fi

PHP_PATH=`which php`

rm -f $PWD/datai
ln -s $DATAI $PWD/datai
rm -f $HTDOCS/webcgi
ln -s $PWD/htdocs $HTDOCS/webcgi

GROUP=`id -gn $USER`
sed -i -e "s%DataPath=.*%DataPath=$PWD/datai/%ig" "$PWD/irbis_server_ft.ini"
sed -i -e "s%WorkDir=.*%WorkDir=$PWD/workdir/%ig" "$PWD/irbis_server_ft.ini"
sed -i -e "s%SysPath=.*%SysPath=$PWD/%ig" "$PWD/irbis_server_ft.ini"
sed -i -e "s%DEPOSITPATH=.*%DEPOSITPATH=$PWD/deposit_plus/%ig" "$PWD/irbis_server_ft.ini"
sed -i -e "s%CgiFlc=.*%CgiFlc=$PWD/deposit_plus/cgiflc.pft%ig" "$PWD/irbis_server_ft.ini"
sed -i -e "s%LIBDIR=.*%LIBDIR=$PWD/%ig" "$PWD/irbis_server_ft.ini"
sed -i -e "s%/var/www/html/web/*%$PWD/%ig" "$PWD/irbis_server_ft.ini"
sed -i -e "s%PHP_PATH=.*%PHP_PATH=$PHP_PATH%ig" "$PWD/irbis_server_ft.ini"

sed -i -e "s%WEBIRBIS=.*%WEBIRBIS=$PWD/%ig" "$SERVER64/irbisa.ini"
sed -i -e "s%WEBIRBIS_INI_NAME=.*%WEBIRBIS_INI_NAME=irbis_server_ft.ini%ig" "$SERVER64/irbisa.ini"

sed -i -e "s%Environment=\"LD_LIBRARY_PATH=.*\"%Environment=\"LD_LIBRARY_PATH=$PWD:$PWD/usr/lib\"%ig" "$PWD/irbis_webcgi.service"
sed -i -e "s%WorkingDirectory=.*%WorkingDirectory=$PWD%ig" "$PWD/irbis_webcgi.service"
sed -i -e "s%ExecStart=.*%ExecStart=$PWD/irbis_webcgi srv%ig" "$PWD/irbis_webcgi.service"
sed -i -e "s%User=.*%User=$USER%ig" "$PWD/irbis_webcgi.service"
sed -i -e "s%Group=.*%Group=$GROUP%ig" "$PWD/irbis_webcgi.service"

chown -R $USER:$GROUP "$PWD"

ln -s libex64.so ex64
ln -s libmyunifor.so myunifor
ln -s libsnr.so SnR
#ln -s libstdc++.so.6.0.21 libstdc++.so.6
declare -a execfiles=(
"install.sh" "irbis_webcgi"
"service_install.sh" "service_remove.sh"
"service_start.sh" "service_stop.sh" "test_start.sh"
)
for file in ${execfiles[@]}
do
    chmod +x $PWD/$file
done

#deleting old service
systemctl stop irbis_webcgi
systemctl disable irbis_webcgi

#installing service
echo "Установка сервиса"
cp -f $PWD/irbis_webcgi.service /etc/systemd/system && systemctl enable irbis_webcgi
#starting service
echo "Запуск сервиса"
systemctl start irbis_webcgi && ps aux | grep "[i]rbis_webcgi"
if pgrep -x "irbis_server" > /dev/null
then
    echo "Сервис запущен"
else
    echo "Сервис не запущен!!!"
fi

echo "Конфигурация apache"
#debian
if [ -f "/etc/apache2/envvars" ]; then
    cp $PWD/apache/debian/etc/apache2/conf-available/*.conf /etc/apache2/conf-available/
    cp $PWD/apache/debian/etc/apache2/conf-enabled/*.conf /etc/apache2/conf-enabled/
    sed -i -e "s%export APACHE_RUN_USER=.*%export APACHE_RUN_USER=$USER%ig" "/etc/apache2/envvars"
    sed -i -e "s%export APACHE_RUN_GROUP=.*%export APACHE_RUN_GROUP=$GROUP%ig" "/etc/apache2/envvars"
    sed -i -e "s%AstraMode on%AstraMode off%ig" "/etc/apache2/apache2.conf"
    sed -i -e "s%# AstraMode .*%AstraMode off%ig" "/etc/apache2/apache2.conf"
    echo "Конфигурация настроена"
    systemctl restart apache2
#redhat
elif [ -f "/etc/httpd/conf/httpd.conf" ]; then
    cp $PWD/apache/redhat/etc/httpd/conf.modules.d/*.conf /etc/httpd/conf.modules.d/
    sed -i -e "s%User .*%User $USER%ig" "/etc/httpd/conf/httpd.conf"
    sed -i -e "s%Group .*%Group $GROUP%ig" "/etc/httpd/conf/httpd.conf"
    echo "Конфигурация настроена"
    systemctl restart httpd
else
    echo "Конфигурация apache не найдена!!!"
    exit
fi
if [ -z "$PHP_PATH" ]
then
      echo "Php не найден. Для использования функциональности, связанной с php, например доступ к ЭБС, установите php и настройте параметр [WEB] PHP_PATH по инструкции"
else
      echo "Доступ к php настроен через вызов исполняемого файла $PHP_PATH"
      echo "Для большей производительности функциональности, связанной с php, например доступ к ЭБС, настройте доступ к php по FASTCGI в параметре [WEB] PHP_PATH по инструкции"
fi
echo "Для проверки работоспособности модуля откройте в браузере url адрес http://localhost/webcgi/"